DigipeatConfig

Struct DigipeatConfig 

pub struct DigipeatConfig {
    pub ui_digipeat: bool,
    pub ui_check: bool,
    pub ui_flood: FloodAlias,
    pub ui_flood_substitute: bool,
    pub ui_trace: TraceAlias,
    pub my_alias: [DigipeatAlias; 4],
}
APRS digipeater (digital repeater) configuration.

The TH-D75 can function as a fill-in digipeater, relaying packets from other APRS stations.

  • Menu No. 580: UIdigipeat on/off
  • Menu No. 581: UIflood alias
  • Menu No. 582: UIflood substitution
  • Menu No. 583: UItrace alias
  • Menu No. 584-587: My Alias 1-4
  • Menu No. 588: UIcheck

UIdigipeat enables relaying of received UI (Unnumbered Information) frames. UIflood handles the “flood” style of digipeating where the hop count is decremented but the alias is not changed (unless substitution is on). UItrace handles “trace” style digipeating where the digipeater inserts its own callsign into the path.

Fields

ui_digipeat: bool

Enable UIdigipeat (relay UI frames).

ui_check: bool

Enable UIcheck (display frames before relaying).

ui_flood: FloodAlias

UIflood alias (e.g. “WIDE1”) for New-N paradigm digipeating.

ui_flood_substitute: bool

UIflood substitution (replace alias with own callsign).

ui_trace: TraceAlias

UItrace alias (e.g. “WIDE2”) for traced digipeating.

my_alias: [DigipeatAlias; 4]

Digipeater MY alias slots (up to 4 additional aliases).